pub trait Validate {
type Error;
// Required method
fn validate(&self) -> Result<(), Self::Error>;
}Expand description
A trait for types which validate their state before construction finishes.
The generated builder will call this method if the #[builder(validate)] attribute is placed at the struct level.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".